@@ -488,10 +488,10 @@ public ANTLRParser(ParserSharedInputState state) {
 		case DOC_COMMENT:
 		case TOKENS:
 		case TOKEN_REF:
-		case RULE_REF:
 		case LITERAL_protected:
 		case LITERAL_public:
 		case LITERAL_private:
+		case RULE_REF:
 		{
 			break;
 		}
@@ -514,10 +514,10 @@ public ANTLRParser(ParserSharedInputState state) {
 		case ACTION:
 		case DOC_COMMENT:
 		case TOKEN_REF:
-		case RULE_REF:
 		case LITERAL_protected:
 		case LITERAL_public:
 		case LITERAL_private:
+		case RULE_REF:
 		{
 			break;
 		}
@@ -540,10 +540,10 @@ public ANTLRParser(ParserSharedInputState state) {
 		}
 		case DOC_COMMENT:
 		case TOKEN_REF:
-		case RULE_REF:
 		case LITERAL_protected:
 		case LITERAL_public:
 		case LITERAL_private:
+		case RULE_REF:
 		{
 			break;
 		}
@@ -601,10 +601,10 @@ public ANTLRParser(ParserSharedInputState state) {
 		case DOC_COMMENT:
 		case TOKENS:
 		case TOKEN_REF:
-		case RULE_REF:
 		case LITERAL_protected:
 		case LITERAL_public:
 		case LITERAL_private:
+		case RULE_REF:
 		{
 			break;
 		}
@@ -627,10 +627,10 @@ public ANTLRParser(ParserSharedInputState state) {
 		case ACTION:
 		case DOC_COMMENT:
 		case TOKEN_REF:
-		case RULE_REF:
 		case LITERAL_protected:
 		case LITERAL_public:
 		case LITERAL_private:
+		case RULE_REF:
 		{
 			break;
 		}
@@ -653,10 +653,10 @@ public ANTLRParser(ParserSharedInputState state) {
 		}
 		case DOC_COMMENT:
 		case TOKEN_REF:
-		case RULE_REF:
 		case LITERAL_protected:
 		case LITERAL_public:
 		case LITERAL_private:
+		case RULE_REF:
 		{
 			break;
 		}
@@ -737,10 +737,10 @@ public ANTLRParser(ParserSharedInputState state) {
 		case DOC_COMMENT:
 		case TOKENS:
 		case TOKEN_REF:
-		case RULE_REF:
 		case LITERAL_protected:
 		case LITERAL_public:
 		case LITERAL_private:
+		case RULE_REF:
 		{
 			break;
 		}
@@ -763,10 +763,10 @@ public ANTLRParser(ParserSharedInputState state) {
 		case ACTION:
 		case DOC_COMMENT:
 		case TOKEN_REF:
-		case RULE_REF:
 		case LITERAL_protected:
 		case LITERAL_public:
 		case LITERAL_private:
+		case RULE_REF:
 		{
 			break;
 		}
@@ -789,10 +789,10 @@ public ANTLRParser(ParserSharedInputState state) {
 		}
 		case DOC_COMMENT:
 		case TOKEN_REF:
-		case RULE_REF:
 		case LITERAL_protected:
 		case LITERAL_public:
 		case LITERAL_private:
+		case RULE_REF:
 		{
 			break;
 		}
@@ -1265,25 +1265,13 @@ public ANTLRParser(ParserSharedInputState state) {
 		
 		match(LPAREN);
 		if ( inputState.guessing==0 ) {
-			sup = LT(1).getText();
+			
+						sup = LT(1).getText();
+						sup = StringUtils.stripFrontBack(sup, "\"", "\"");
+						
 		}
 		{
-		switch ( LA(1)) {
-		case TOKEN_REF:
-		{
-			match(TOKEN_REF);
-			break;
-		}
-		case RULE_REF:
-		{
-			match(RULE_REF);
-			break;
-		}
-		default:
-		{
-			throw new NoViableAltException(LT(1), getFilename());
-		}
-		}
+		match(STRING_LITERAL);
 		}
 		match(RPAREN);
 		return sup;
@@ -1318,10 +1306,10 @@ public ANTLRParser(ParserSharedInputState state) {
 			break;
 		}
 		case TOKEN_REF:
-		case RULE_REF:
 		case LITERAL_protected:
 		case LITERAL_public:
 		case LITERAL_private:
+		case RULE_REF:
 		{
 			break;
 		}
@@ -1526,10 +1514,10 @@ public ANTLRParser(ParserSharedInputState state) {
 		case LITERAL_lexclass:
 		case LITERAL_class:
 		case TOKEN_REF:
-		case RULE_REF:
 		case LITERAL_protected:
 		case LITERAL_public:
 		case LITERAL_private:
+		case RULE_REF:
 		{
 			break;
 		}
@@ -1674,9 +1662,9 @@ public ANTLRParser(ParserSharedInputState state) {
 		case OR:
 		case TOKEN_REF:
 		case LPAREN:
-		case RULE_REF:
 		case RPAREN:
 		case LITERAL_exception:
+		case RULE_REF:
 		case NOT_OP:
 		case SEMPRED:
 		case TREE_BEGIN:
@@ -1747,9 +1735,9 @@ public ANTLRParser(ParserSharedInputState state) {
 		case OR:
 		case TOKEN_REF:
 		case LPAREN:
-		case RULE_REF:
 		case RPAREN:
 		case LITERAL_exception:
+		case RULE_REF:
 		case NOT_OP:
 		case SEMPRED:
 		case TREE_BEGIN:
@@ -1812,12 +1800,12 @@ public ANTLRParser(ParserSharedInputState state) {
 		case LITERAL_lexclass:
 		case LITERAL_class:
 		case TOKEN_REF:
-		case RULE_REF:
 		case LITERAL_protected:
 		case LITERAL_public:
 		case LITERAL_private:
 		case LITERAL_exception:
 		case LITERAL_catch:
+		case RULE_REF:
 		{
 			break;
 		}
@@ -1948,10 +1936,10 @@ public ANTLRParser(ParserSharedInputState state) {
 					case TOKEN_REF:
 					case OPEN_ELEMENT_OPTION:
 					case LPAREN:
-					case RULE_REF:
 					case RPAREN:
 					case BANG:
 					case LITERAL_exception:
+					case RULE_REF:
 					case NOT_OP:
 					case SEMPRED:
 					case TREE_BEGIN:
@@ -1983,9 +1971,9 @@ public ANTLRParser(ParserSharedInputState state) {
 					case TOKEN_REF:
 					case OPEN_ELEMENT_OPTION:
 					case LPAREN:
-					case RULE_REF:
 					case RPAREN:
 					case LITERAL_exception:
+					case RULE_REF:
 					case NOT_OP:
 					case SEMPRED:
 					case TREE_BEGIN:
@@ -2027,9 +2015,9 @@ public ANTLRParser(ParserSharedInputState state) {
 					case TOKEN_REF:
 					case OPEN_ELEMENT_OPTION:
 					case LPAREN:
-					case RULE_REF:
 					case RPAREN:
 					case LITERAL_exception:
+					case RULE_REF:
 					case NOT_OP:
 					case SEMPRED:
 					case TREE_BEGIN:
@@ -2096,10 +2084,10 @@ public ANTLRParser(ParserSharedInputState state) {
 					case TOKEN_REF:
 					case OPEN_ELEMENT_OPTION:
 					case LPAREN:
-					case RULE_REF:
 					case RPAREN:
 					case BANG:
 					case LITERAL_exception:
+					case RULE_REF:
 					case NOT_OP:
 					case SEMPRED:
 					case TREE_BEGIN:
@@ -2131,9 +2119,9 @@ public ANTLRParser(ParserSharedInputState state) {
 					case TOKEN_REF:
 					case OPEN_ELEMENT_OPTION:
 					case LPAREN:
-					case RULE_REF:
 					case RPAREN:
 					case LITERAL_exception:
+					case RULE_REF:
 					case NOT_OP:
 					case SEMPRED:
 					case TREE_BEGIN:
@@ -2276,9 +2264,9 @@ public ANTLRParser(ParserSharedInputState state) {
 			case TOKEN_REF:
 			case OPEN_ELEMENT_OPTION:
 			case LPAREN:
-			case RULE_REF:
 			case RPAREN:
 			case LITERAL_exception:
+			case RULE_REF:
 			case NOT_OP:
 			case SEMPRED:
 			case TREE_BEGIN:
@@ -2403,9 +2391,9 @@ public ANTLRParser(ParserSharedInputState state) {
 			case TOKEN_REF:
 			case OPEN_ELEMENT_OPTION:
 			case LPAREN:
-			case RULE_REF:
 			case RPAREN:
 			case LITERAL_exception:
+			case RULE_REF:
 			case NOT_OP:
 			case SEMPRED:
 			case TREE_BEGIN:
@@ -2448,9 +2436,9 @@ public ANTLRParser(ParserSharedInputState state) {
 			case TOKEN_REF:
 			case OPEN_ELEMENT_OPTION:
 			case LPAREN:
-			case RULE_REF:
 			case RPAREN:
 			case LITERAL_exception:
+			case RULE_REF:
 			case NOT_OP:
 			case SEMPRED:
 			case TREE_BEGIN:
@@ -2527,9 +2515,9 @@ public ANTLRParser(ParserSharedInputState state) {
 			case TOKEN_REF:
 			case OPEN_ELEMENT_OPTION:
 			case LPAREN:
-			case RULE_REF:
 			case RPAREN:
 			case LITERAL_exception:
+			case RULE_REF:
 			case NOT_OP:
 			case SEMPRED:
 			case TREE_BEGIN:
@@ -2631,10 +2619,10 @@ public ANTLRParser(ParserSharedInputState state) {
 		case TOKEN_REF:
 		case OPEN_ELEMENT_OPTION:
 		case LPAREN:
-		case RULE_REF:
 		case RPAREN:
 		case BANG:
 		case LITERAL_exception:
+		case RULE_REF:
 		case NOT_OP:
 		case SEMPRED:
 		case TREE_BEGIN:
@@ -2677,10 +2665,10 @@ public ANTLRParser(ParserSharedInputState state) {
 			case TOKEN_REF:
 			case OPEN_ELEMENT_OPTION:
 			case LPAREN:
-			case RULE_REF:
 			case RPAREN:
 			case BANG:
 			case LITERAL_exception:
+			case RULE_REF:
 			case NOT_OP:
 			case SEMPRED:
 			case TREE_BEGIN:
@@ -2712,9 +2700,9 @@ public ANTLRParser(ParserSharedInputState state) {
 			case TOKEN_REF:
 			case OPEN_ELEMENT_OPTION:
 			case LPAREN:
-			case RULE_REF:
 			case RPAREN:
 			case LITERAL_exception:
+			case RULE_REF:
 			case NOT_OP:
 			case SEMPRED:
 			case TREE_BEGIN:
@@ -2838,10 +2826,10 @@ public ANTLRParser(ParserSharedInputState state) {
 		case TOKEN_REF:
 		case OPEN_ELEMENT_OPTION:
 		case LPAREN:
-		case RULE_REF:
 		case RPAREN:
 		case ARG_ACTION:
 		case LITERAL_exception:
+		case RULE_REF:
 		case NOT_OP:
 		case SEMPRED:
 		case TREE_BEGIN:
@@ -2888,7 +2876,6 @@ public ANTLRParser(ParserSharedInputState state) {
 		"OPEN_ELEMENT_OPTION",
 		"CLOSE_ELEMENT_OPTION",
 		"LPAREN",
-		"RULE_REF",
 		"RPAREN",
 		"\"Parser\"",
 		"\"protected\"",
@@ -2902,6 +2889,7 @@ public ANTLRParser(ParserSharedInputState state) {
 		"COMMA",
 		"\"exception\"",
 		"\"catch\"",
+		"RULE_REF",
 		"NOT_OP",
 		"SEMPRED",
 		"TREE_BEGIN",
@@ -2927,37 +2915,37 @@ public ANTLRParser(ParserSharedInputState state) {
 	};
 	
 	private static final long[] mk_tokenSet_0() {
-		long[] data = { 15317598464L, 0L};
+		long[] data = { 2206556225792L, 0L};
 		return data;
 	}
 	public static final BitSet _tokenSet_0 = new BitSet(mk_tokenSet_0());
 	private static final long[] mk_tokenSet_1() {
-		long[] data = { 547893559424L, 0L};
+		long[] data = { 2472844214400L, 0L};
 		return data;
 	}
 	public static final BitSet _tokenSet_1 = new BitSet(mk_tokenSet_1());
 	private static final long[] mk_tokenSet_2() {
-		long[] data = { 1156686652375232L, 0L};
+		long[] data = { 1158885407195328L, 0L};
 		return data;
 	}
 	public static final BitSet _tokenSet_2 = new BitSet(mk_tokenSet_2());
 	private static final long[] mk_tokenSet_3() {
-		long[] data = { 1157838276198592L, 0L};
+		long[] data = { 1159461236965568L, 0L};
 		return data;
 	}
 	public static final BitSet _tokenSet_3 = new BitSet(mk_tokenSet_3());
 	private static final long[] mk_tokenSet_4() {
-		long[] data = { 1130298373308480L, 0L};
+		long[] data = { 1132497128128576L, 0L};
 		return data;
 	}
 	public static final BitSet _tokenSet_4 = new BitSet(mk_tokenSet_4());
 	private static final long[] mk_tokenSet_5() {
-		long[] data = { 1720925672784064L, 0L};
+		long[] data = { 1722479914074304L, 0L};
 		return data;
 	}
 	public static final BitSet _tokenSet_5 = new BitSet(mk_tokenSet_5());
 	private static final long[] mk_tokenSet_6() {
-		long[] data = { 1720788233830592L, 0L};
+		long[] data = { 1722411194597568L, 0L};
 		return data;
 	}
 	public static final BitSet _tokenSet_6 = new BitSet(mk_tokenSet_6());
@@ -2967,22 +2955,22 @@ public ANTLRParser(ParserSharedInputState state) {
 	}
 	public static final BitSet _tokenSet_7 = new BitSet(mk_tokenSet_7());
 	private static final long[] mk_tokenSet_8() {
-		long[] data = { 1720788229619904L, 0L};
+		long[] data = { 1722411190386880L, 0L};
 		return data;
 	}
 	public static final BitSet _tokenSet_8 = new BitSet(mk_tokenSet_8());
 	private static final long[] mk_tokenSet_9() {
-		long[] data = { 1157803882840256L, 0L};
+		long[] data = { 1159444023476416L, 0L};
 		return data;
 	}
 	public static final BitSet _tokenSet_9 = new BitSet(mk_tokenSet_9());
 	private static final long[] mk_tokenSet_10() {
-		long[] data = { 2250890277404864L, 0L};
+		long[] data = { 2251345007067328L, 0L};
 		return data;
 	}
 	public static final BitSet _tokenSet_10 = new BitSet(mk_tokenSet_10());
 	private static final long[] mk_tokenSet_11() {
-		long[] data = { 1719688145404096L, 0L};
+		long[] data = { 1721861130420416L, 0L};
 		return data;
 	}
 	public static final BitSet _tokenSet_11 = new BitSet(mk_tokenSet_11());
