@@ -2,9 +2,9 @@ package antlr;
 
 /* ANTLR Translator Generator
  * Project led by Terence Parr at http://www.jGuru.com
- * Software rights: http://www.antlr.org/RIGHTS.html
+ * Software rights: http://www.antlr.org/license.html
  *
- * $Id: //depot/code/org.antlr/release/antlr-2.7.2/antlr/LLkAnalyzer.java#1 $
+ * $Id: //depot/code/org.antlr/release/antlr-2.7.4/antlr/LLkAnalyzer.java#1 $
  */
 
 import antlr.collections.impl.BitSet;
@@ -405,14 +405,33 @@ public class LLkAnalyzer implements LLkGrammarAnalyzer {
                 return (Lookahead)end.cache[k].clone();
             }
             else {
-                // replace this cache entry with the entry from the referenced computation.
-                // Eventually, this percolates a complete (no cycle reference) cache entry
-                // to this node (or at least gets it closer and closer).  This is not
-                // crucial, but makes cache lookup faster as we might have to look up
-                // lots of cycle references before finding a complete reference.
-                end.cache[k] = re.cache[k];
-                // Return the cache entry associated with the cycle reference.
-                return (Lookahead)re.cache[k].clone();
+                if (DEBUG_ANALYZER) {
+                    System.out.println("combining FOLLOW(" + k + ") for " + rule + ": from "+end.cache[k].toString(",", charFormatter, grammar) + " with FOLLOW for "+((RuleBlock)re.block).getRuleName()+": "+re.cache[k].toString(",", charFormatter, grammar));
+                }
+                // combine results from other rule's FOLLOW
+                if ( re.cache[k].cycle==null ) {
+                    // current rule depends on another rule's FOLLOW and
+                    // it is complete with no cycle; just kill our cycle and
+                    // combine full result from other rule's FOLLOW
+                    end.cache[k].combineWith(re.cache[k]);
+                    end.cache[k].cycle = null; // kill cycle as we're complete
+                }
+                else {
+                    // the FOLLOW cache for other rule has a cycle also.
+                    // Here is where we bubble up a cycle.  We better recursively
+                    // wipe out cycles (partial computations).  I'm a little nervous
+                    // that we might leave a cycle here, however.
+                    Lookahead refFOLLOW = FOLLOW(k, re);
+                    end.cache[k].combineWith( refFOLLOW );
+                    // all cycles should be gone, but if not, record ref to cycle
+                    end.cache[k].cycle = refFOLLOW.cycle;
+                }
+                if (DEBUG_ANALYZER) {
+                    System.out.println("saving FOLLOW(" + k + ") for " + rule + ": from "+end.cache[k].toString(",", charFormatter, grammar));
+                }
+                // Return the updated cache entry associated
+                // with the cycle reference.
+                return (Lookahead)end.cache[k].clone();
             }
         }
 
