@@ -2,9 +2,9 @@ package antlr;
 
 /* ANTLR Translator Generator
  * Project led by Terence Parr at http://www.jGuru.com
- * Software rights: http://www.antlr.org/RIGHTS.html
+ * Software rights: http://www.antlr.org/license.html
  *
- * $Id: //depot/code/org.antlr/release/antlr-2.7.2/antlr/NoViableAltException.java#1 $
+ * $Id: //depot/code/org.antlr/release/antlr-2.7.4/antlr/NoViableAltException.java#1 $
  */
 
 import antlr.collections.AST;
@@ -14,7 +14,7 @@ public class NoViableAltException extends RecognitionException {
     public AST node;	// handles parsing and treeparsing
 
     public NoViableAltException(AST t) {
-        super("NoViableAlt", "<AST>", -1, -1);
+        super("NoViableAlt", "<AST>", t.getLine(), t.getColumn());
         node = t;
     }
 
