@@ -2,9 +2,9 @@ package antlr;
 
 /* ANTLR Translator Generator
  * Project led by Terence Parr at http://www.jGuru.com
- * Software rights: http://www.antlr.org/RIGHTS.html
+ * Software rights: http://www.antlr.org/license.html
  *
- * $Id: //depot/code/org.antlr/release/antlr-2.7.2/antlr/Tool.java#1 $
+ * $Id: //depot/code/org.antlr/release/antlr-2.7.4/antlr/Tool.java#1 $
  */
 
 import java.io.*;
@@ -377,7 +377,7 @@ public static Object factory2 (String p, Object[] initargs) {
 
     public static void main(String[] args) {
         System.err.println("ANTLR Parser Generator   Version " +
-                           Version.project_version + "   1989-2003 jGuru.com");
+                           Version.project_version + "   1989-2004 jGuru.com");
         version = Version.project_version;
 
         try {
@@ -412,12 +412,17 @@ public static Object factory2 (String p, Object[] initargs) {
         System.exit(0);
     }
 
-    /** This method is used by all code generators to create new output
-     * files.
-     */
-    public PrintWriter openOutputFile(String f) throws IOException {
-        return new PrintWriter(new PreservingFileWriter(outputDir + System.getProperty("file.separator") + f));
-    }
+	/** This method is used by all code generators to create new output
+	 * files. If the outputDir set by -o is not present it will be created here.
+	 */
+	public PrintWriter openOutputFile(String f) throws IOException {
+		if( outputDir != "." ) {
+			File out_dir = new File(outputDir);
+			if( ! out_dir.exists() )
+				out_dir.mkdirs();
+		}
+		return new PrintWriter(new PreservingFileWriter(outputDir + System.getProperty("file.separator") + f));
+	}
 
     public Reader getGrammarReader() {
         Reader f = null;
@@ -501,22 +506,11 @@ public static Object factory2 (String p, Object[] initargs) {
      *  of the elements.
      */
     public static Vector parseSeparatedList(String list, char separator) {
+        java.util.StringTokenizer st =
+		new java.util.StringTokenizer(list, String.valueOf(separator));
         Vector v = new Vector(10);
-        StringBuffer buf = new StringBuffer(100);
-        int i = 0;
-        while (i < list.length()) {
-            while (i < list.length() && list.charAt(i) != separator) {
-                buf.append(list.charAt(i));
-                i++;
-            }
-            // add element to vector
-            v.appendElement(buf.toString());
-            buf.setLength(0);
-            // must be a separator or finished.
-            if (i < list.length()) {
-                // not done?
-                i++;    // skip separator
-            }
+        while ( st.hasMoreTokens() ) {
+             v.appendElement(st.nextToken());
         }
         if (v.size() == 0) return null;
         return v;
@@ -629,7 +623,7 @@ public static Object factory2 (String p, Object[] initargs) {
     }
 
     /**
-     * Support C++ & C# namespaces (for now).  
+     * Support C++ & C# namespaces (for now).
      * C++: Add a nested namespace name to the current namespace.
      * C# : Specify an enclosing namespace for the generated code.
      * DAW: David Wagner -- C# support by kunle odutola
