@@ -3,9 +3,9 @@
 
 /* ANTLR Translator Generator
  * Project led by Terence Parr at http://www.jGuru.com
- * Software rights: http://www.antlr.org/RIGHTS.html
+ * Software rights: http://www.antlr.org/license.html
  *
- * $Id: //depot/code/org.antlr/release/antlr-2.7.2/lib/cpp/antlr/CommonAST.hpp#1 $
+ * $Id: //depot/code/org.antlr/release/antlr-2.7.4/lib/cpp/antlr/CommonAST.hpp#1 $
  */
 
 #include <antlr/config.hpp>
@@ -42,6 +42,7 @@ public:
 
 	static RefAST factory();
 
+	static const char* const TYPE_NAME;
 protected:
 	int ttype;
 	ANTLR_USE_NAMESPACE(std)string text;
