@@ -3,9 +3,9 @@
 
 /* ANTLR Translator Generator
  * Project led by Terence Parr at http://www.jGuru.com
- * Software rights: http://www.antlr.org/RIGHTS.html
+ * Software rights: http://www.antlr.org/license.html
  *
- * $Id: //depot/code/org.antlr/release/antlr-2.7.2/lib/cpp/antlr/String.hpp#1 $
+ * $Id: //depot/code/org.antlr/release/antlr-2.7.4/lib/cpp/antlr/String.hpp#1 $
  */
 
 #include <antlr/config.hpp>
@@ -15,9 +15,9 @@
 namespace antlr {
 #endif
 
-ANTLR_USE_NAMESPACE(std)string operator+(const ANTLR_USE_NAMESPACE(std)string& lhs,const int rhs);
+ANTLR_API ANTLR_USE_NAMESPACE(std)string operator+(const ANTLR_USE_NAMESPACE(std)string& lhs,const int rhs);
 
-ANTLR_USE_NAMESPACE(std)string charName(int ch);
+ANTLR_API ANTLR_USE_NAMESPACE(std)string charName(int ch);
 
 #ifdef ANTLR_CXX_SUPPORTS_NAMESPACE
 }
