@@ -2,7 +2,7 @@ namespace antlr
 {
 	/*ANTLR Translator Generator
 	* Project led by Terence Parr at http://www.jGuru.com
-	* Software rights: http://www.antlr.org/RIGHTS.html
+	* Software rights: http://www.antlr.org/license.html
 	*
 	* $Id: $
 	*/
@@ -17,6 +17,7 @@ namespace antlr
 	
 	using System;
 	
+	[Serializable]
 	public class ANTLRPanicException : ANTLRException 
 	{
 		public ANTLRPanicException() : base() 
