@@ -1,4 +1,5 @@
 using System;
+using System.Collections;
 using Assembly			= System.Reflection.Assembly;
 using ArrayList			= System.Collections.ArrayList;
 using Debug				= System.Diagnostics.Debug;
@@ -10,7 +11,7 @@ namespace antlr
 {
 	/*ANTLR Translator Generator
 	* Project led by Terence Parr at http://www.jGuru.com
-	* Software rights: http://www.antlr.org/RIGHTS.html
+	* Software rights: http://www.antlr.org/license.html
 	*
 	* $Id: $
 	*/
@@ -71,6 +72,11 @@ namespace antlr
 		{
 			nodeTypeObjectList_ = new Type[Token.MIN_USER_TYPE+1];
 			defaultASTNodeTypeObject_ = loadNodeTypeObject(nodeTypeName);
+			defaultCreator_				= null;
+			typename2creator_			= new Hashtable(32, (float) 0.3);
+			typename2creator_["antlr.CommonAST"]					= CommonAST.Creator;
+			typename2creator_["antlr.CommonASTWithHiddenTokens"]	= CommonASTWithHiddenTokens.Creator;
+
 		}
 		
 		//---------------------------------------------------------------------
@@ -81,12 +87,18 @@ namespace antlr
 		/// Stores the Type of the default AST node class to be used during tree construction.
 		/// </summary>
 		protected Type			defaultASTNodeTypeObject_;
+		protected ASTNodeCreator	defaultCreator_;
 
 		/// <summary>
 		/// Stores the mapping between custom AST NodeTypes and their NodeTypeName/NodeTypeClass.
 		/// </summary>
 		protected Type[]		nodeTypeObjectList_;
 
+		/// <summary>
+		/// Stores the mapping between AST node typenames and their token ID.
+		/// </summary>
+		protected Hashtable			typename2creator_;
+
 		//---------------------------------------------------------------------
 		// FUNCTION MEMBERS
 		//---------------------------------------------------------------------
@@ -131,6 +143,26 @@ namespace antlr
 			setTokenTypeASTNodeType(NodeType, NodeTypeName);
 		}
 
+		/// <summary>
+		/// Register an ASTNodeCreator for a given Token type ID.
+		/// </summary>
+		/// <param name="NodeType">The Token type ID.</param>
+		/// <param name="NodeTypeName">The AST Node Type to register.</param>
+		public void setTokenTypeASTNodeCreator(int NodeType, ASTNodeCreator creator)
+		{
+			typename2creator_[NodeType.ToString()]		= creator;
+			typename2creator_[creator.ASTNodeTypeName]	= creator;
+		}
+
+		/// <summary>
+		/// Register an ASTNodeCreator to be used for creating node by default.
+		/// </summary>
+		/// <param name="creator">The ASTNodeCreator.</param>
+		public void setASTNodeCreator(ASTNodeCreator creator)
+		{
+			defaultCreator_ = creator;
+		}
+
 		/// <summary>
 		/// Pre-expands the internal list of TokenTypeID-to-ASTNodeType mappings
 		/// to the specified size.
@@ -205,7 +237,13 @@ namespace antlr
 		/// <returns>An uninitialized AST node object.</returns>
 		public virtual AST create()
 		{
-			AST newNode = createFromNodeTypeObject(defaultASTNodeTypeObject_);
+			AST newNode;
+			
+			if (defaultCreator_ == null)
+				newNode = createFromNodeTypeObject(defaultASTNodeTypeObject_);
+			else
+				newNode = defaultCreator_.Create();
+
 			return newNode;
 		}
 		
@@ -302,7 +340,7 @@ namespace antlr
 				newNode = null;
 			else
 			{			
-				newNode = createFromNodeTypeObject(aNode.GetType());
+				newNode = createFromAST(aNode);
 				newNode.initialize(aNode);
 			}
 			return newNode;
@@ -345,11 +383,9 @@ namespace antlr
 			if (t == null)
 				return null;
 
-			AST dup_edNode = createFromNodeTypeObject(t.GetType());
+			AST dup_edNode = createFromAST(t);
 			dup_edNode.initialize(t);
 			return dup_edNode;
-
-			//return (AST)((t == null) ? null : t.Clone());
 		}
 		
 		/// <summary>
@@ -474,6 +510,13 @@ namespace antlr
 		/// <param name="t">Fully qualified AST Node Type name.</param>
 		public virtual void  setASTNodeType(string t)
 		{
+			if (defaultCreator_ != null)
+			{
+				if (t != defaultCreator_.ASTNodeTypeName)
+				{
+					defaultCreator_ = null;
+				}
+			}
 			defaultASTNodeTypeObject_ = loadNodeTypeObject(t);
 		}
 		
@@ -523,20 +566,73 @@ namespace antlr
 			return nodeTypeObject;
 		}
 
+		private AST createFromAST(AST node)
+		{
+			AST		newNode			= null;
+			Type	nodeAsTypeObj	= node.GetType();
+
+			ASTNodeCreator creator = (ASTNodeCreator) typename2creator_[nodeAsTypeObj.FullName];
+			if (creator != null)
+			{
+				newNode = creator.Create();
+				if (newNode == null)
+				{
+					throw new ArgumentException("Unable to create AST Node Type: '" + nodeAsTypeObj.FullName + "'");
+				}
+			}
+			else
+			{
+				newNode = createFromNodeTypeObject(nodeAsTypeObj);
+			}
+			return newNode;
+		}
+
 		private AST createFromNodeName(string nodeTypeName)
 		{
-			return createFromNodeTypeObject( loadNodeTypeObject(nodeTypeName) );
+			AST		newNode			= null;
+
+			ASTNodeCreator creator = (ASTNodeCreator) typename2creator_[nodeTypeName];
+			if (creator != null)
+			{
+				newNode = creator.Create();
+				if (newNode == null)
+				{
+					throw new ArgumentException("Unable to create AST Node Type: '" + nodeTypeName + "'");
+				}
+			}
+			else
+			{
+				newNode = createFromNodeTypeObject( loadNodeTypeObject(nodeTypeName) );
+			}
+			return newNode;
 		}
 
 		private AST createFromNodeType(int nodeTypeIndex)
 		{
 			Debug.Assert((nodeTypeIndex >= 0) && (nodeTypeIndex <= nodeTypeObjectList_.Length), "Invalid AST node type!");
+			AST newNode = null;
 
-			Type nodeTypeObject = nodeTypeObjectList_[nodeTypeIndex];
-			if (nodeTypeObject == null)
-				nodeTypeObject = defaultASTNodeTypeObject_;
-
-			return createFromNodeTypeObject( nodeTypeObject );
+			ASTNodeCreator creator = (ASTNodeCreator) typename2creator_[nodeTypeIndex.ToString()];
+			if (creator != null)
+			{
+				newNode = creator.Create();
+			}
+			else
+			{
+				Type nodeTypeObject = nodeTypeObjectList_[nodeTypeIndex];
+				if (nodeTypeObject == null)
+				{
+					if (defaultCreator_ == null)
+					{
+						newNode = createFromNodeTypeObject(defaultASTNodeTypeObject_);
+					}
+					else
+						newNode = defaultCreator_.Create();
+				}
+				else
+                    newNode = createFromNodeTypeObject( nodeTypeObject );
+			}
+			return newNode;
 		}
 
 		private AST createFromNodeTypeObject(Type nodeTypeObject)
