@@ -1,4 +1,6 @@
 using System;
+using Stream			= System.IO.Stream;
+using TextReader		= System.IO.TextReader;
 using StringBuilder		= System.Text.StringBuilder;
 using Hashtable			= System.Collections.Hashtable;
 using Assembly			= System.Reflection.Assembly;
@@ -11,7 +13,7 @@ namespace antlr
 {
 	/*ANTLR Translator Generator
 	* Project led by Terence Parr at http://www.jGuru.com
-	* Software rights: http://www.antlr.org/RIGHTS.html
+	* Software rights: http://www.antlr.org/license.html
 	*
 	* $Id: $
 	*/
@@ -57,12 +59,14 @@ namespace antlr
 
 		protected internal StringBuilder text;				// text of current token
 		
-		protected internal bool saveConsumedInput = true;	// does consume() save characters?
-		protected internal string tokenObjectTypeName;		// what kind of tokens to create?
-		protected Type			  tokenObjectType;			// template for creating tokens...
-		protected internal bool caseSensitive = true;
-		protected internal bool caseSensitiveLiterals = true;
-		protected internal Hashtable literals; // set by subclass
+		protected bool saveConsumedInput = true;	// does consume() save characters?
+
+		/// <summary>Used for creating Token instances.</summary>
+		protected TokenCreator	tokenCreator;
+
+		protected bool caseSensitive = true;
+		protected bool caseSensitiveLiterals = true;
+		protected Hashtable literals; // set by subclass
 		
 		/*Tab chars are handled by tab() according to this value; override
 		*  method to do anything weird with tabs.
@@ -85,7 +89,7 @@ namespace antlr
 		public CharScanner()
 		{
 			text = new StringBuilder();
-			setTokenObjectClass("antlr.CommonToken");
+			setTokenCreator(new CommonToken.CommonTokenCreator());
 		}
 		
 		public CharScanner(InputBuffer cb) : this()
@@ -196,7 +200,7 @@ namespace antlr
 		}
 
 		// From interface TokenStream
-		public Token nextToken() { return null; }
+		public virtual Token nextToken() { return null; }
 
 		public virtual void  append(char c)
 		{
@@ -344,13 +348,14 @@ namespace antlr
 
 			try
 			{
-				newToken = (Token)Activator.CreateInstance(tokenObjectType);
+				newToken = tokenCreator.Create();
 				if (newToken != null)
 				{
 					newToken.Type = t;
 					newToken.setColumn(inputState.tokenStartColumn);
 					newToken.setLine(inputState.tokenStartLine);
 					// tracking real start line now: newToken.setLine(inputState.line);
+					newToken.setFilename(inputState.filename);
 				}
 				typeCreated	= true;
 			}
@@ -361,7 +366,7 @@ namespace antlr
 
 			if (!typeCreated)
 			{
-				panic("Can't create Token object '" + tokenObjectTypeName + "'");
+				panic("Can't create Token object '" + tokenCreator.TokenTypeName + "'");
 				newToken = Token.badToken;
 			}
 			return (Token)newToken;
@@ -374,7 +379,7 @@ namespace antlr
 		
 		public virtual void  match(char c)
 		{
-			match(Convert.ToInt32(c));
+			match((int) c);
 		}
 
 		public virtual void  match(int c)
@@ -392,10 +397,7 @@ namespace antlr
 			{
 				throw new MismatchedCharException(LA(1), b, false, this);
 			}
-			else
-			{
-				consume();
-			}
+			consume();
 		}
 		
 		public virtual void  match(string s)
@@ -413,7 +415,7 @@ namespace antlr
 		
 		public virtual void  matchNot(char c)
 		{
-			matchNot(Convert.ToInt32(c));
+			matchNot((int) c);
 		}
 		
 		public virtual void  matchNot(int c)
@@ -434,7 +436,7 @@ namespace antlr
 		
 		public virtual void  matchRange(char c1, char c2)
 		{
-			matchRange(Convert.ToInt32(c1), Convert.ToInt32(c2));
+			matchRange((int) c1, (int) c2);
 		}
 		
 		public virtual void  newline()
@@ -518,6 +520,23 @@ namespace antlr
 			}
 		}
 		
+		public virtual void resetState(InputBuffer ib)
+		{
+			text.Length = 0;
+			traceDepth = 0;
+			inputState.resetInput(ib);
+		}
+
+		public void resetState(Stream s)
+		{
+			resetState(new ByteBuffer(s));
+		}
+
+		public void resetState(TextReader tr)
+		{
+			resetState(new CharBuffer(tr));
+		}
+
 		public virtual void  resetText()
 		{
 			text.Length = 0;
@@ -559,40 +578,27 @@ namespace antlr
 		
 		public virtual void  setTokenObjectClass(string cl)
 		{
-			tokenObjectTypeName = cl;
-			foreach (Assembly assem in AppDomain.CurrentDomain.GetAssemblies())
-			{
-				try
-				{
-					tokenObjectType = assem.GetType(tokenObjectTypeName);
-					if (tokenObjectType != null)
-					{
-						break;
-					}
-				}
-				catch
-				{
-					throw new TypeLoadException("Unable to load Type for Token class '" + tokenObjectTypeName + "'");
-				}
-			}
-			if (tokenObjectType==null)
-				throw new TypeLoadException("Unable to load Type for Token class '" + tokenObjectTypeName + "'");
+			this.tokenCreator = new ReflectionBasedTokenCreator(this, cl);
+		}
+		
+		public virtual void  setTokenCreator(TokenCreator tokenCreator)
+		{
+			this.tokenCreator = tokenCreator;
 		}
 		
 		// Test the token text against the literals table
 		// Override this method to perform a different literals test
 		public virtual int testLiteralsTable(int ttype)
 		{
-			try
-			{
-				int literalsIndex = (int) literals[text.ToString()];
-				ttype = literalsIndex;
+			string tokenText = text.ToString();
+
+			if ( (tokenText == null) || (tokenText == string.Empty) )
 				return ttype;
+			else
+			{
+				object typeAsObject = literals[tokenText];
+				return (typeAsObject == null) ? ttype : ((int) typeAsObject);
 			}
-			catch
-			{
-				return ttype;
-			}		
 		}
 		
 		/*Test the text passed in against the literals table
@@ -602,22 +608,19 @@ namespace antlr
 		*/
 		public virtual int testLiteralsTable(string someText, int ttype)
 		{
-			try
-			{
-				int literalsIndex = (int) literals[someText];
-				ttype = literalsIndex;
+			if ( (someText == null) || (someText == string.Empty) )
 				return ttype;
+			else
+			{
+				object typeAsObject = literals[someText];
+				return (typeAsObject == null) ? ttype : ((int) typeAsObject);
 			}
-			catch
-			{
-				return ttype;
-			}		
 		}
 		
 		// Override this method to get more specific case handling
 		public virtual char toLower(int c)
 		{
-			return Char.ToLower(Convert.ToChar(c));
+			return Char.ToLower(Convert.ToChar(c), System.Globalization.CultureInfo.InvariantCulture);
 		}
 		
 		public virtual void  traceIndent()
@@ -658,5 +661,84 @@ namespace antlr
 		public virtual void  uponEOF()
 		{
 		}
+
+		private class ReflectionBasedTokenCreator : TokenCreator
+		{
+			protected ReflectionBasedTokenCreator() {}
+
+			public ReflectionBasedTokenCreator(CharScanner owner, string tokenTypeName)
+			{
+				this.owner = owner;
+				SetTokenType(tokenTypeName);
+			}
+
+			private CharScanner owner;
+
+			/// <summary>
+			/// The fully qualified name of the Token type to create.
+			/// </summary>
+			private string tokenTypeName;
+
+			/// <summary>
+			/// Type object used as a template for creating tokens by reflection.
+			/// </summary>
+			private Type tokenTypeObject;
+
+			/// <summary>
+			/// Returns the fully qualified name of the Token type that this
+			/// class creates.
+			/// </summary>
+			private void SetTokenType(string tokenTypeName)
+			{
+				this.tokenTypeName = tokenTypeName;
+				foreach (Assembly assem in AppDomain.CurrentDomain.GetAssemblies())
+				{
+					try
+					{
+						tokenTypeObject = assem.GetType(tokenTypeName);
+						if (tokenTypeObject != null)
+						{
+							break;
+						}
+					}
+					catch
+					{
+						throw new TypeLoadException("Unable to load Type for Token class '" + tokenTypeName + "'");
+					}
+				}
+				if (tokenTypeObject==null)
+					throw new TypeLoadException("Unable to load Type for Token class '" + tokenTypeName + "'");
+			}
+
+			/// <summary>
+			/// Returns the fully qualified name of the Token type that this
+			/// class creates.
+			/// </summary>
+			public override string TokenTypeName
+			{
+				get
+				{ 
+					return tokenTypeName; 
+				}
+			}
+
+			/// <summary>
+			/// Constructs a <see cref="Token"/> instance.
+			/// </summary>
+			public override Token Create()
+			{
+				Token newToken = null;
+
+				try
+				{
+					newToken = (Token) Activator.CreateInstance(tokenTypeObject);
+				}
+				catch
+				{
+					// supress exception
+				}
+				return (Token)newToken;
+			}
+		}
 	}
 }
\ No newline at end of file
