@@ -4,7 +4,7 @@ namespace antlr
 {
 	/*ANTLR Translator Generator
 	* Project led by Terence Parr at http://www.jGuru.com
-	* Software rights: http://www.antlr.org/RIGHTS.html
+	* Software rights: http://www.antlr.org/license.html
 	*
 	* $Id: $
 	*/
@@ -21,6 +21,7 @@ namespace antlr
 	* Anything that goes wrong while generating a stream of characters
 	*/
 
+	[Serializable]
 	public class CharStreamException : ANTLRException
 	{
 		/*
