@@ -5,7 +5,7 @@ namespace antlr
 {
 	/*ANTLR Translator Generator
 	* Project led by Terence Parr at http://www.jGuru.com
-	* Software rights: http://www.antlr.org/RIGHTS.html
+	* Software rights: http://www.antlr.org/license.html
 	*
 	* $Id: $
 	*/
@@ -21,6 +21,7 @@ namespace antlr
 	/*
 	* Wrap an IOException in a CharStreamException
 	*/
+	[Serializable]
 	public class CharStreamIOException : CharStreamException
 	{
 		public IOException io;
