@@ -4,7 +4,7 @@ namespace antlr
 {
 	/*ANTLR Translator Generator
 	* Project led by Terence Parr at http://www.jGuru.com
-	* Software rights: http://www.antlr.org/RIGHTS.html
+	* Software rights: http://www.antlr.org/license.html
 	*
 	* $Id: $
 	*/
@@ -19,6 +19,8 @@ namespace antlr
 	
 	public class CommonHiddenStreamToken : CommonToken
 	{
+		new public static readonly CommonHiddenStreamToken.CommonHiddenStreamTokenCreator Creator = new CommonHiddenStreamTokenCreator();
+
 		protected internal CommonHiddenStreamToken hiddenBefore;
 		protected internal CommonHiddenStreamToken hiddenAfter;
 		
@@ -53,5 +55,30 @@ namespace antlr
 		{
 			hiddenBefore = t;
 		}
+
+		public class CommonHiddenStreamTokenCreator : TokenCreator
+		{
+			public CommonHiddenStreamTokenCreator() {}
+
+			/// <summary>
+			/// Returns the fully qualified name of the Token type that this
+			/// class creates.
+			/// </summary>
+			public override string TokenTypeName
+			{
+				get 
+				{ 
+					return typeof(antlr.CommonHiddenStreamToken).FullName;; 
+				}
+			}
+
+			/// <summary>
+			/// Constructs a <see cref="Token"/> instance.
+			/// </summary>
+			public override Token Create()
+			{
+				return new CommonHiddenStreamToken();
+			}
+		}
 	}
 }
\ No newline at end of file
