@@ -4,7 +4,7 @@ namespace antlr
 {
 	/*ANTLR Translator Generator
 	* Project led by Terence Parr at http://www.jGuru.com
-	* Software rights: http://www.antlr.org/RIGHTS.html
+	* Software rights: http://www.antlr.org/license.html
 	*
 	* $Id: $
 	*/
@@ -19,6 +19,8 @@ namespace antlr
 
 	public class CommonToken : Token
 	{
+		public static readonly CommonToken.CommonTokenCreator Creator = new CommonTokenCreator();
+
 		// most tokens will want line and text information
 		protected internal int line;
 		protected internal string text = null;
@@ -74,5 +76,30 @@ namespace antlr
 		{
 			col = c;
 		}
+
+		public class CommonTokenCreator : TokenCreator
+		{
+			public CommonTokenCreator() {}
+
+			/// <summary>
+			/// Returns the fully qualified name of the Token type that this
+			/// class creates.
+			/// </summary>
+			public override string TokenTypeName
+			{
+				get 
+				{ 
+					return typeof(antlr.CommonToken).FullName;; 
+				}
+			}
+
+			/// <summary>
+			/// Constructs a <see cref="Token"/> instance.
+			/// </summary>
+			public override Token Create()
+			{
+				return new CommonToken();
+			}
+		}
 	}
 }
\ No newline at end of file
