@@ -6,7 +6,7 @@ namespace antlr
 {
 	/*ANTLR Translator Generator
 	* Project led by Terence Parr at http://www.jGuru.com
-	* Software rights: http://www.antlr.org/RIGHTS.html
+	* Software rights: http://www.antlr.org/license.html
 	*
 	* $Id: $
 	*/
@@ -19,6 +19,7 @@ namespace antlr
 	// With many thanks to Eric V. Smith from the ANTLR list.
 	//
 	
+	[Serializable]
 	public class NoViableAltException : RecognitionException
 	{
 		public Token token;
