@@ -4,7 +4,7 @@ namespace antlr
 {
 	/*ANTLR Translator Generator
 	* Project led by Terence Parr at http://www.jGuru.com
-	* Software rights: http://www.antlr.org/RIGHTS.html
+	* Software rights: http://www.antlr.org/license.html
 	*
 	* $Id: $
 	*/
@@ -17,6 +17,7 @@ namespace antlr
 	// With many thanks to Eric V. Smith from the ANTLR list.
 	//
 
+	[Serializable]
 	public class SemanticException : RecognitionException
 	{
 		public SemanticException(string s) : base(s)
