@@ -4,7 +4,7 @@ namespace antlr
 {
 	/*ANTLR Translator Generator
 	* Project led by Terence Parr at http://www.jGuru.com
-	* Software rights: http://www.antlr.org/RIGHTS.html
+	* Software rights: http://www.antlr.org/license.html
 	*
 	* $Id: $
 	*/
@@ -22,6 +22,7 @@ namespace antlr
 	* can pass it along.
 	*/
 
+	[Serializable]
 	public class TokenStreamRecognitionException : TokenStreamException
 	{
 		public RecognitionException recog;
