@@ -4,7 +4,7 @@ namespace antlr
 {
 	/*ANTLR Translator Generator
 	* Project led by Terence Parr at http://www.jGuru.com
-	* Software rights: http://www.antlr.org/RIGHTS.html
+	* Software rights: http://www.antlr.org/license.html
 	*
 	* $Id: $
 	*/
@@ -23,6 +23,7 @@ namespace antlr
 	* of stream to re-enter and retry.
 	*/
 
+	[Serializable]
 	public class TokenStreamRetryException : TokenStreamException
 	{
 		public TokenStreamRetryException() {}
