@@ -4,7 +4,7 @@ namespace antlr
 {
 	/*ANTLR Translator Generator
 	* Project led by Terence Parr at http://www.jGuru.com
-	* Software rights: http://www.antlr.org/RIGHTS.html
+	* Software rights: http://www.antlr.org/license.html
 	*
 	* $Id: $
 	*/
@@ -28,5 +28,10 @@ namespace antlr
 	{
 		/*Are we guessing (guessing>0)? */
 		public int guessing = 0;
+
+		public virtual void reset()
+		{
+			guessing = 0;
+		}
 	}
 }
\ No newline at end of file
